
From: Eric W. Biederman <ebiederm@xmission.com>

The i8259 does not yet have sysfs support on x86_64 so here is the port from
i386, including the shutdown code to disable it on reboot that kexec
appreciates.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/x86_64/kernel/i8259.c |   38 +++++++++++++++++++++++++++++++++++++
 1 files changed, 38 insertions(+)

diff -puN arch/x86_64/kernel/i8259.c~kexec-i8259-sysfsx86_64 arch/x86_64/kernel/i8259.c
--- 25/arch/x86_64/kernel/i8259.c~kexec-i8259-sysfsx86_64	Fri Aug 20 15:21:59 2004
+++ 25-akpm/arch/x86_64/kernel/i8259.c	Fri Aug 20 15:21:59 2004
@@ -343,6 +343,44 @@ spurious_8259A_irq:
 	}
 }
 
+static int i8259A_resume(struct sys_device *dev)
+{
+	init_8259A(0);
+	return 0;
+}
+
+static int i8259A_shutdown(struct sys_device *dev)
+{
+	/* Put the i8259A into a quiescent state that
+	 * the kernel initialization code can get it
+	 * out of.
+	 */
+	outb(0xff, 0x21);	/* mask all of 8259A-1 */
+	outb(0xff, 0xA1);	/* mask all of 8259A-1 */
+	return 0;
+}
+
+static struct sysdev_class i8259_sysdev_class = {
+	set_kset_name("i8259"),
+	.resume = i8259A_resume,
+	.shutdown = i8259A_shutdown,
+};
+
+static struct sys_device device_i8259A = {
+	.id	= 0,
+	.cls	= &i8259_sysdev_class,
+};
+
+static int __init i8259A_init_sysfs(void)
+{
+	int error = sysdev_class_register(&i8259_sysdev_class);
+	if (!error)
+		error = sysdev_register(&device_i8259A);
+	return error;
+}
+
+device_initcall(i8259A_init_sysfs);
+
 void init_8259A(int auto_eoi)
 {
 	unsigned long flags;
_
